@@ -34,6 +34,10 @@ class Logger():
             time_tuple = time.localtime(time.time())
             # 把是时间元组，转换成时间字符串
             time_str = time.strftime("%Y%m%d",time_tuple)
+            # 如果日志文件的文件夹不存在，则创建
+            if os.path.exists(os.path.join(os.getcwd(),"logs")):
+                os.makedirs(os.path.join(os.getcwd(),"logs"))
+
             __class__.__file_name = os.path.join(os.getcwd(),"logs",f"{time_str}-")
         return self.__file_name
 
